@@ -7,13 +7,15 @@ use File::Slurp;
 use Exporter;
 use parent 'Exporter';
 
-our $VERSION = '0.02';
-our @EXPORT  = qw /compare/;
+our $VERSION = '0.03';
+our @EXPORT  = qw "compare catch_cmd";
 
 sub usage () {
     say "\n网络配置基线巡检模块使用说明：\n";
     say
         "\n加载模块后，需传入compare函数（基线配置路径，设备运行配置路径）\n";
+    say
+        "\n加载模块后，需传入catch_cmd函数（待捕捉的命令行，巡检输出）\n";
     say '\n使用过程如有任何疑问，请联系careline@126.com\n';
     exit(-1);
 }
@@ -175,4 +177,69 @@ sub compare {
     return $report;
 }
 
+#------------------------------------------------------------------
+# 网络配置基线巡检-捕捉命令行输出
+#------------------------------------------------------------------
+sub catch_cmd {
+
+    #状态巡检命令输入
+    my $cmd = shift;
+
+    #状态巡检命令输出
+    my $config = shift;
+
+    #检查入参是否完整
+    unless ( $cmd && $config ) {
+        &usage();
+    }
+
+    #将命令行转数组
+    my @config = map { $_ = s/\n//r } read_file($config);
+
+    #检验是否命中规则
+    my $hit_cmd = ( grep {/$cmd\s?$/} @config ) ? 1 : 0;
+
+    #如果未命中命令行则跳出函数
+    return unless $hit_cmd;
+
+    #巡检命令行命中计数器
+    my ( $result, $hit_count );
+
+    #遍历状态巡检输出
+    foreach my $cli (@config) {
+
+        #跳转空白行
+        next unless $cli;
+
+        #命中CLI后将配置写入并设置状态
+        if ( $cli =~ /$cmd\s?$/ ) {
+
+            #将命中文本写入
+            push @{$result}, $cli;
+            $hit_count = 1;
+
+        }
+
+        #匹配到描述性分隔符退出遍历
+        elsif ( $hit_count && $cli =~ /^\<(.*)\>/ ) {
+
+            #改写命中状态
+            $hit_count = 0;
+
+            #跳出循环
+            last;
+        }
+
+        #将非空文本写入
+        elsif ($hit_count) {
+
+            #将非空文本写入
+            push @{$result}, $cli;
+        }
+    }
+
+    #返回结果
+    return $result;
+}
+
 1;
